@@ -21,13 +21,12 @@ import os
 
 from pyb_init.tasks import ShellCommandTask, PreconditionTask
 from pyb_init.vcs_tools import determine_project_name_from_git_url
-
-VIRTUALENV_NAME = 'virtualenv'
+from pyb_init.configuration import configuration
 
 
 def for_local_initialization():
     reactor = TaskReactor()
-    _add_common_tasks(virtualenv_name=VIRTUALENV_NAME, reactor=reactor, command_prefix=None)
+    _add_common_tasks(reactor=reactor, command_prefix=None)
     return reactor
 
 
@@ -40,14 +39,14 @@ def for_git_clone(git_url):
     reactor = TaskReactor()
     reactor.add_task(ShellCommandTask('git clone {0}'.format(git_url)))
     project = determine_project_name_from_git_url(git_url)
-    _add_common_tasks(virtualenv_name=VIRTUALENV_NAME,
-                      reactor=reactor,
+    _add_common_tasks(reactor=reactor,
                       command_prefix='cd {0} && '.format(project),
                       project=project)
     return reactor
 
 
-def _add_common_tasks(virtualenv_name, reactor, command_prefix, project=None):
+def _add_common_tasks(reactor, command_prefix, project=None):
+    virtualenv_name = configuration['virtualenv_name']
     _add_preconditions(reactor, project)
     commands = ['virtualenv {0} --clear'.format(virtualenv_name),
                 'source {0}/bin/activate && pip install pybuilder'.format(virtualenv_name),
